# Description
Helpfull scripts for doing computational chemistry

# Latest updates
Support for orca input file creation\
Customizable use of .com or .gjf extensions\
Bug fixes and other customizations

# Installing
"cd" to the directory that contains the 'setup.py' file.\
Run one of the following commands as apropriated (including the dot character):
```bash
py -m pip install .
```
```bash
python3 -m pip install .
```
```bash
pip3 install .
```
```bash
python -m pip install .
```
```bash
pip install .
```
Note for those who had installed previous versions of this software:\
Manually delete the old "raachem" if you had it (pre installer versions).
# Running
After installation is complete, you should be able to run the module from any folder using one of the following:
```bash
py -m raachem
```
```bash
python3 -m raachem
```
```bash
python -m raachem
```
Done! The script operates on files in the current working directory!
# Uninstalling
Run one of the following commands as apropriated:
```bash
py -m pip uninstall raachem
```
```bash
python3 -m pip uninstall raachem
```
```bash
pip3 uninstall raachem
```
```bash
python -m pip uninstall raachem
```
```bash
pip uninstall raachem
```
